@@ -46,7 +46,7 @@ globalVariables(c("Marker", "p.value"))
 ##' test_segregation_of_a_marker(onemap_example_out,1)
 ##' 
 ##' @export
-test_segregation_of_a_marker <- function(x, marker, simulate.p.value=TRUE) {
+test_segregation_of_a_marker <- function(x, marker, simulate.p.value=FALSE) {
   # Break if marker has any genotype information
   if(all(x$geno[,marker] ==0)) {
     warning(cat("Marker", marker, "do not have genotype information for any sample. We suggest to remove it from the dataset\n"))
@@ -158,7 +158,7 @@ test_segregation_of_a_marker <- function(x, marker, simulate.p.value=TRUE) {
 ##' }
 ##' 
 ##' @export
-test_segregation <- function(x, simulate.p.value = TRUE) {
+test_segregation <- function(x, simulate.p.value = FALSE) {
     if (is(x,"onemap")) {
         y <- list(Marker=dimnames(x$geno)[[2]],
                   Results.of.tests=sapply(1:x$n.mar, function(onemap.object, marker)
